@@ -1,8 +1,7 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 #
-# vim: sw=2 ts=2 sts=2
-#
-# Copyright 2007 The Python-Twitter Developers
+# Copyright 2007-2018 The Python-Twitter Developers
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,14 +15,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""A library that provides a Python interface to the Twitter API"""
+"""A library that provides a Python interface to the Twitter API."""
 from __future__ import absolute_import
 
 __author__       = 'The Python-Twitter Developers'
 __email__        = 'python-twitter@googlegroups.com'
 __copyright__    = 'Copyright (c) 2007-2016 The Python-Twitter Developers'
 __license__      = 'Apache License 2.0'
-__version__      = '3.4'
+__version__      = '3.4.2'
 __url__          = 'https://github.com/bear/python-twitter'
 __download_url__ = 'https://pypi.python.org/pypi/python-twitter'
 __description__  = 'A Python wrapper around the Twitter API'
