@@ -28,6 +28,13 @@ class TwitterModel(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def __hash__(self):
+        if hasattr(self, 'id'):
+            return hash(self.id)
+        else:
+            raise TypeError('unhashable type: {} (no id attribute)'
+                            .format(type(self)))
+
     def AsJsonString(self):
         """ Returns the TwitterModel as a JSON string based on key/value
         pairs returned from the AsDict() method. """
@@ -275,12 +282,12 @@ class UserStatus(TwitterModel):
     """ A class representing the UserStatus structure. This is an abbreviated
     form of the twitter.User object. """
 
-    connections = {'following': False,
-                   'followed_by': False,
-                   'following_received': False,
-                   'following_requested': False,
-                   'blocking': False,
-                   'muting': False}
+    _connections = {'following': False,
+                    'followed_by': False,
+                    'following_received': False,
+                    'following_requested': False,
+                    'blocking': False,
+                    'muting': False}
 
     def __init__(self, **kwargs):
         self.param_defaults = {
@@ -300,10 +307,19 @@ class UserStatus(TwitterModel):
             setattr(self, param, kwargs.get(param, default))
 
         if 'connections' in kwargs:
-            for param in self.connections:
+            for param in self._connections:
                 if param in kwargs['connections']:
                     setattr(self, param, True)
 
+    @property
+    def connections(self):
+        return {'following': self.following,
+                'followed_by': self.followed_by,
+                'following_received': self.following_received,
+                'following_requested': self.following_requested,
+                'blocking': self.blocking,
+                'muting': self.muting}
+
     def __repr__(self):
         connections = [param for param in self.connections if getattr(self, param)]
         return "UserStatus(ID={uid}, ScreenName={sn}, Connections=[{conn}])".format(
@@ -330,6 +346,7 @@ class User(TwitterModel):
             'friends_count': None,
             'geo_enabled': None,
             'id': None,
+            'id_str': None,
             'lang': None,
             'listed_count': None,
             'location': None,
@@ -337,12 +354,16 @@ class User(TwitterModel):
             'notifications': None,
             'profile_background_color': None,
             'profile_background_image_url': None,
+            'profile_background_image_url_https': None,
             'profile_background_tile': None,
             'profile_banner_url': None,
             'profile_image_url': None,
+            'profile_image_url_https': None,
             'profile_link_color': None,
+            'profile_sidebar_border_color': None,
             'profile_sidebar_fill_color': None,
             'profile_text_color': None,
+            'profile_use_background_image': None,
             'protected': None,
             'screen_name': None,
             'status': None,
@@ -351,6 +372,8 @@ class User(TwitterModel):
             'url': None,
             'utc_offset': None,
             'verified': None,
+            'withheld_in_countries': None,
+            'withheld_scope': None,
         }
 
         for (param, default) in self.param_defaults.items():
@@ -476,6 +499,11 @@ class Status(TwitterModel):
         user = None
         user_mentions = None
 
+        # for loading extended tweets from the streaming API.
+        if 'extended_tweet' in data:
+            for k, v in data['extended_tweet'].items():
+                data[k] = v
+
         if 'user' in data:
             user = User.NewFromJsonDict(data['user'])
         if 'retweeted_status' in data:
